@@ -168,6 +168,8 @@ def build_channel(self, channelfile, ignore=['data/', 'output/'], verify=False):
     """
     import os
     import docker
+    import json
+    import shutil
     import time
     import subprocess
     from anatools.lib.print import print_color
@@ -176,6 +178,31 @@ def build_channel(self, channelfile, ignore=['data/', 'output/'], verify=False):
     try: dockerclient = docker.APIClient(base_url='unix://var/run/docker.sock')
     except: raise Exception('Cannot connect to Docker host.')
 
+    # check System and Docker space usage
+    try:
+        disk_usage = shutil.disk_usage('/')
+        gb_free = disk_usage.free / (1024**3)  # Convert bytes to GB
+        if self.verbose == 'debug': print(f"Disk space left: {gb_free:.3f}GB")
+        if gb_free < 20: print_color(f'\nWarning: Low disk space detected! Only {gb_free:.1f}GB available.', 'ffff00')
+        docker_space_cmd = "docker system df --format json"
+        result = subprocess.run(docker_space_cmd, shell=True, capture_output=True, text=True)
+        if result.returncode == 0:
+            docker_stats = json.loads(result.stdout)
+            total_docker_size = sum(item.get('Size', 0) for item in docker_stats if 'Size' in item)
+            docker_gb = total_docker_size / (1024**3)  # Convert bytes to GB
+            if self.verbose == 'debug': print(f"Docker space used: {docker_gb:.3f}GB")
+            if docker_gb > 20:
+                print_color(f'\nWarning: Docker is using {docker_gb:.1f}GB of disk space!', 'ffff00')
+                print_color('Consider running "docker system prune -a" to free up space.', 'ffff00')
+                print_color('This will remove:', 'ffff00')
+                print_color('  - All stopped containers', 'ffff00')
+                print_color('  - All networks not used by at least one container', 'ffff00')
+                print_color('  - All dangling images', 'ffff00')
+                print_color('  - All dangling build cache', 'ffff00')
+    except Exception as e:
+        print(e)
+        pass
+
     # build dockerfile
     print('Building Channel Image...', end='', flush=True)    
     if not os.path.isfile(channelfile): raise Exception(f'No channel file {channelfile} found.')
