@@ -139,7 +139,7 @@ def delete_service(self, serviceId):
     return result
 
 
-def build_service(self, servicefile, ignore=['data/', 'output/'], verify=False):
+def build_service(self, servicefile, ignore=['data/', 'output/']):
     """Build the Docker image of a service.
     
     Parameters
@@ -148,8 +148,6 @@ def build_service(self, servicefile, ignore=['data/', 'output/'], verify=False):
         The service file for the service to build.
     ignore : list, optional
         List of files or directories to ignore during the build.
-    verify : bool, optional
-        If True, verifies the image by running the anautils command.
 
     Returns
     -------
@@ -158,6 +156,7 @@ def build_service(self, servicefile, ignore=['data/', 'output/'], verify=False):
     """
     import os
     import docker
+    import json
     import time
     import shutil
     import subprocess
@@ -168,6 +167,30 @@ def build_service(self, servicefile, ignore=['data/', 'output/'], verify=False):
     try: dockerclient = docker.APIClient(base_url='unix://var/run/docker.sock')
     except: raise Exception('Cannot connect to Docker host.')    
 
+    # check System and Docker space usage
+    try:
+        disk_usage = shutil.disk_usage('/')
+        gb_free = disk_usage.free / (1024**3)  # Convert bytes to GB
+        if self.verbose == 'debug': print(f"Disk space left: {gb_free:.3f}GB")
+        if gb_free < 20: print_color(f'\nWarning: Low disk space detected! Only {gb_free:.1f}GB available.', 'ffff00')
+        docker_space_cmd = "docker system df --format json"
+        result = subprocess.run(docker_space_cmd, shell=True, capture_output=True, text=True)
+        if result.returncode == 0:
+            docker_stats = json.loads(result.stdout)
+            total_docker_size = sum(item.get('Size', 0) for item in docker_stats if 'Size' in item)
+            docker_gb = total_docker_size / (1024**3)  # Convert bytes to GB
+            if self.verbose == 'debug': print(f"Docker space used: {docker_gb:.3f}GB")
+            if docker_gb > 20:
+                print_color(f'\nWarning: Docker is using {docker_gb:.1f}GB of disk space!', 'ffff00')
+                print_color('Consider running "docker system prune -a" to free up space.', 'ffff00')
+                print_color('This will remove:', 'ffff00')
+                print_color('  - All stopped containers', 'ffff00')
+                print_color('  - All networks not used by at least one container', 'ffff00')
+                print_color('  - All dangling images', 'ffff00')
+                print_color('  - All dangling build cache', 'ffff00')
+    except Exception as e:
+        pass
+
     # check for service Dockerfile
     print('Building Service Image...', end='', flush=True)    
     if not os.path.isfile(servicefile): raise Exception(f'No service file {servicefile} found.')
@@ -190,7 +213,15 @@ def build_service(self, servicefile, ignore=['data/', 'output/'], verify=False):
     # call the docker build command
     try:
         start = time.time()
-        streamer = dockerclient.build(path=servicedir, dockerfile=os.path.join(servicedir, '.devcontainer/Dockerfile'), tag=image, rm=True, decode=True, platform='linux/amd64')
+        streamer = dockerclient.build(
+            path=servicedir, 
+            dockerfile=os.path.join(servicedir, '.devcontainer/Dockerfile'), 
+            tag=image, 
+            rm=True, 
+            decode=True, 
+            platform='linux/amd64', 
+            nocache=False,
+            pull=False)
         logfilepath = os.path.join(tempfile.gettempdir(), 'dockerbuild.log')
         logfile = open(logfilepath, 'w')
         while True:
@@ -216,22 +247,6 @@ def build_service(self, servicefile, ignore=['data/', 'output/'], verify=False):
         raise Exception(f'Error encountered while building Docker image. Please check logfile {logfilepath}.')
     if self.verbose != 'debug' and os.path.exists(logfilepath): os.remove(logfilepath)
     print(f"\rBuilding Service Image...done.  [{time.time()-start:.3f}s]", flush=True)
-
-    # check that image is valid by running anautils command
-    if verify:
-        try:
-            print(f'Verifying Service Image...', end='', flush=True)
-            start = time.time()
-            container_name = f"anadeploy-service-{imgtime}"
-            command = f'docker run --name {container_name} --entrypoint "" {image} anautils --mode=schema --output=/tmp'
-            result = subprocess.run(command, shell=True, stdout=subprocess.DEVNULL, stderr=subprocess.PIPE, text=True)
-            if result.returncode != 0:
-                print_color(f"\n\n{result.stderr}\n", "ff0000")
-                raise Exception(f'Error encountered while verifying Docker image with the anautils command.')
-            print(f"\rVerifying Service Image...done. [{time.time()-start:.3f}s]") 
-            subprocess.run(f'docker rm {container_name}', shell=True, stdout=subprocess.DEVNULL, stderr=subprocess.DEVNULL)
-        except Exception as e: raise Exception(f'Error encountered while verifying Docker image. Please check that you can generate the schema using the anautils command.')
-
     return image
 
 
@@ -259,7 +274,7 @@ def deploy_service(self, serviceId=None, servicefile=None):
     if serviceId is None and image is None: raise Exception('The serviceId or local image must be specified.')
     try: dockerclient = docker.from_env()
     except: raise Exception('Error connecting to Docker.')
-    image = self.build_service(servicefile, verify=True)
+    image = self.build_service(servicefile)
     try: serviceimage = dockerclient.images.get(image)
     except docker.errors.ImageNotFound: raise Exception(f'Could not find Docker image with name "{image}".')
     except: raise Exception('Error connecting to Docker.')
